@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# $Id: actionsportlet.py 86466 2009-05-20 09:33:08Z piv $
+# $Id: actionsportlet.py 114310 2010-03-30 16:07:23Z glenfant $
 """Actions portlet"""
 
 from Acquisition import aq_inner
@@ -29,7 +29,7 @@ class IActionsPortlet(IPortletDataProvider):
         description=_(u'help_title',
                       default=u"Displayed title of this portlet"),
         default=u"",
-        required=True)
+        required=False)
 
     category = schema.Choice(
         title=_(u'label_actions_category',
@@ -81,7 +81,7 @@ class Assignment(base.Assignment):
         """This property is used to give the title of the portlet in the
         "manage portlets" screen.
         """
-        return _(u"Actions portlet") + ' "%s"' % self.ptitle
+        return _(u"Actions portlet") + ' "%s"' % (self.ptitle or self.category)
 
 
 class Renderer(base.Renderer):
@@ -111,13 +111,13 @@ class Renderer(base.Renderer):
     def cachedLinks(self, actions_category, default_icon, show_icons):
         context_state = getMultiAdapter((aq_inner(self.context), self.request),
                                         name=u'plone_context_state')
-        actions = context_state.actions().get(actions_category, [])
+        actions = context_state.actions()
 
         # Finding method for icons
         if show_icons:
             portal_actionicons = getToolByName(self.context, 'portal_actionicons')
             def render_icon(category, action, default):
-                if action['icon']:
+                if action.has_key('icon') and action['icon']:
                     # We have an icon *in* this action
                     return action['icon']
                 # Otherwise we look for an icon in portal_actionicons
@@ -129,21 +129,40 @@ class Renderer(base.Renderer):
 
         # Building the result as list of dicts
         result = []
-        for action in actions:
-            if not (action['available']
-                    and action['visible']
-                    and action['allowed']
-                    and action['url']):
-                continue
-            link = {
-                'url': action['url'],
-                'title': action['title'],
-                'icon': render_icon(
-                    actions_category,
-                    action,
-                    default=default_icon)
-                }
-            result.append(link)
+
+        if actions_category=="portal_tabs":
+            # Special case for portal_tabs (we rely on content in Plone root)
+            portal_tabs_view = getMultiAdapter(
+                (self.context, self.context.REQUEST), name='portal_tabs_view')
+            actions = portal_tabs_view.topLevelTabs(actions=actions)
+            for action in actions:
+                link = {
+                    'url': action['url'],
+                    'title': action['name'],
+                    'icon': render_icon(
+                        actions_category,
+                        action,
+                        default=default_icon)
+                    }
+                result.append(link)
+
+        else:
+            actions = actions.get(actions_category, [])
+            for action in actions:
+                if not (action['available']
+                        and action['visible']
+                        and action['allowed']
+                        and action['url']):
+                    continue
+                link = {
+                    'url': action['url'],
+                    'title': action['title'],
+                    'icon': render_icon(
+                        actions_category,
+                        action,
+                        default=default_icon)
+                    }
+                result.append(link)
         return result
 
 
